CoordinatedAbortCleaner

Trait CoordinatedAbortCleaner 

pub trait CoordinatedAbortCleaner: Send + Sync {
    // Required method
    fn cleanup_aborted<'life0, 'async_trait>(
        &'life0 self,
        batch: CoordinatedAbortBatch,
        context: CoordinatedCommitContext,
    ) -> Pin<Box<dyn Future<Output = Result<(), ConnectorError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Recovery-only cleanup capability detached from a participant writer.

Required Methods

fn cleanup_aborted<'life0, 'async_trait>( &'life0 self, batch: CoordinatedAbortBatch, context: CoordinatedCommitContext, ) -> Pin<Box<dyn Future<Output = Result<(), ConnectorError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Release exact durable participant artifacts after an authoritative Abort.

The cleaner must remain usable after the participant writer is closed. Implementations must be idempotent and retain any artifact whose publication status is ambiguous.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors