pub struct KafkaDiscoveryConfig {Show 14 fields
pub bootstrap_servers: String,
pub group_id: String,
pub discovery_topic: String,
pub heartbeat_interval_ms: u64,
pub missed_heartbeat_threshold: u32,
pub dead_heartbeat_threshold: u32,
pub security_protocol: String,
pub sasl_mechanism: Option<String>,
pub sasl_username: Option<String>,
pub sasl_password: Option<String>,
pub node_id: NodeId,
pub rpc_address: String,
pub raft_address: String,
pub node_metadata: NodeMetadata,
}Expand description
Configuration for Kafka-based discovery.
Fields
bootstrap_servers: StringKafka bootstrap servers.
group_id: StringConsumer group ID for discovery.
discovery_topic: StringTopic for discovery messages.
heartbeat_interval_ms: u64How often to publish this node’s heartbeat (ms).
missed_heartbeat_threshold: u32How many missed heartbeats before marking a node as suspected.
dead_heartbeat_threshold: u32How many missed heartbeats before marking a node as left.
security_protocol: StringSASL/SSL configuration for Kafka.
sasl_mechanism: Option<String>SASL mechanism.
sasl_username: Option<String>SASL username.
sasl_password: Option<String>SASL password.
node_id: NodeIdThis node’s ID.
rpc_address: StringThis node’s RPC address.
raft_address: StringThis node’s Raft address.
node_metadata: NodeMetadataThis node’s metadata.