pub fn partition_vnodes(
source_identity: &str,
topic: &str,
total_partitions: i32,
vnode_count: u32,
) -> Result<Vec<u32>, ConnectorError>Expand description
Map a complete Kafka topic inventory to engine vnodes.
Errors
Returns a configuration error when the Kafka route identity, partition inventory, or vnode count is invalid.