pub async fn get_latest_version(
table: &mut DeltaTable,
) -> Result<i64, ConnectorError>Expand description
Returns the latest committed version via the log store.
Errors
Returns ConnectorError::ReadError on failure.
pub async fn get_latest_version(
table: &mut DeltaTable,
) -> Result<i64, ConnectorError>Returns the latest committed version via the log store.
Returns ConnectorError::ReadError on failure.