register_delta_lake_source

Function register_delta_lake_source 

pub fn register_delta_lake_source(
    registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>
Registers the Delta Lake source connector with the given registry.

Errors

Returns the registry error when a name is already registered or the registry is frozen.