register_iceberg_sink

Function register_iceberg_sink 

pub fn register_iceberg_sink(
    registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>
Registers the Iceberg sink connector with the given registry.

Errors

Returns the registry error when a name is already registered or the registry is frozen.