register_iceberg_source

Function register_iceberg_source 

pub fn register_iceberg_source(
    registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>
Registers the Iceberg source connector with the given registry.

Errors

Returns the registry error when a name is already registered or the registry is frozen.