IcebergSink

Struct IcebergSink 

pub struct IcebergSink { /* private fields */ }
Apache Iceberg sink connector.

Buffers RecordBatch data during each checkpoint epoch and commits to an Iceberg table atomically when the epoch commits. Each epoch produces at most one Iceberg transaction.

Implementations

Source

impl IcebergSink

pub fn new(config: IcebergSinkConfig, _registry: Option<&Registry>) -> Self

Creates a new Iceberg sink with the given configuration.