get_last_committed_epoch

Function get_last_committed_epoch 

pub fn get_last_committed_epoch(table: &Table, writer_id: &str) -> Option<u64>
Reads the last committed epoch for a writer from Iceberg table properties.

Returns None if the writer has never committed to this table.