pub fn register_nats_sink(
registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>Expand description
Registers the NATS sink connector.
Errors
Returns an error if the sink is already registered or the registry is frozen.
pub fn register_nats_sink(
registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>Registers the NATS sink connector.
Returns an error if the sink is already registered or the registry is frozen.