pub fn register_nats_source(
registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>Expand description
Registers the NATS source connector.
Errors
Returns an error if the source is already registered or the registry is frozen.
pub fn register_nats_source(
registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>Registers the NATS source connector.
Returns an error if the source is already registered or the registry is frozen.