apply_changes

Function apply_changes 

pub fn apply_changes(
    old: &SchemaRef,
    changes: &[SchemaChange],
) -> SchemaResult<ColumnProjection>
Applies a set of schema changes to produce a new schema and a column projection mapping old columns to new positions.

Errors

Returns SchemaError if the changes reference columns that don’t exist.