pub fn register_mock_sink(
registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>Expand description
Registers a mock sink connector with the registry.
Errors
Returns an error when the mock sink name is already registered.
pub fn register_mock_sink(
registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>Registers a mock sink connector with the registry.
Returns an error when the mock sink name is already registered.