pub fn register_mock_source(
registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>Expand description
Registers a mock source connector with the registry.
Errors
Returns an error when the mock source name is already registered.
pub fn register_mock_source(
registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>Registers a mock source connector with the registry.
Returns an error when the mock source name is already registered.