pub struct MockSourceConnector { /* private fields */ }Expand description
Mock source connector for testing.
Returns a configurable number of batches, then returns None.
Implementations
Sourceimpl MockSourceConnector
impl MockSourceConnector
Sourcepub fn with_batches(count: u64, batch_size: usize) -> Self
pub fn with_batches(count: u64, batch_size: usize) -> Self
Creates a mock source with custom batch count and size.
Sourcepub fn records_produced(&self) -> u64
pub fn records_produced(&self) -> u64
Returns the total records produced.