pub struct WebSocketSinkMetrics {
pub messages_sent: IntCounter,
pub messages_dropped_slow_client: IntCounter,
pub bytes_sent: IntCounter,
pub connected_clients: IntGauge,
pub client_disconnects: IntCounter,
pub replay_requests: IntCounter,
pub ping_timeouts: IntCounter,
}Expand description
Prometheus-backed counters/gauges for WebSocket sink connector statistics.
Fields
messages_sent: IntCounterTotal messages sent to connected clients.
messages_dropped_slow_client: IntCounterTotal messages dropped because a client was too slow.
bytes_sent: IntCounterTotal bytes sent (serialized payload).
connected_clients: IntGaugeCurrent number of connected clients.
client_disconnects: IntCounterTotal client disconnection events.
replay_requests: IntCounterTotal replay requests received from clients.
ping_timeouts: IntCounterTotal clients disconnected due to ping timeout.
Implementations
Sourceimpl WebSocketSinkMetrics
impl WebSocketSinkMetrics
Sourcepub fn new(registry: Option<&Registry>) -> Self
pub fn new(registry: Option<&Registry>) -> Self
Creates a new metrics instance with all counters at zero.
Sourcepub fn record_send(&self, bytes: u64)
pub fn record_send(&self, bytes: u64)
Records a successfully sent message with the given payload size.
Sourcepub fn record_drop(&self)
pub fn record_drop(&self)
Records a message dropped due to a slow client.
Sourcepub fn record_connect(&self)
pub fn record_connect(&self)
Records a new client connection.
Sourcepub fn record_disconnect(&self)
pub fn record_disconnect(&self)
Records a client disconnection.
Sourcepub fn record_replay(&self)
pub fn record_replay(&self)
Records a replay request from a client.
Sourcepub fn record_ping_timeout(&self)
pub fn record_ping_timeout(&self)
Records a client disconnected due to ping timeout.
Sourcepub fn to_connector_metrics(&self) -> ConnectorMetrics
pub fn to_connector_metrics(&self) -> ConnectorMetrics
Converts to the SDK’s ConnectorMetrics.