pub fn strip_source_mutations(
records: &RecordBatch,
) -> Result<RecordBatch, ConnectorError>Expand description
Remove only mutation metadata while retaining the exact trailing row positions.
Errors
Returns an error when any source metadata field is malformed.