pub fn register_kafka_sink(
registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>Expand description
Registers the Kafka sink connector with the given registry.
Errors
Returns an error if a Kafka sink factory is already registered or the registry has been frozen.