pub fn register_kafka_source(
registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>Expand description
Registers the Kafka source connector with the given registry.
Errors
Returns an error if a Kafka source factory is already registered or the registry has been frozen.