pub fn register_kafka_source(registry: &ConnectorRegistry)Expand description
Registers the Kafka source connector with the given registry.
pub fn register_kafka_source(registry: &ConnectorRegistry)Registers the Kafka source connector with the given registry.