pub async fn open_or_create_table(
table_path: &str,
storage_options: HashMap<String, String>,
schema: Option<&SchemaRef>,
) -> Result<DeltaTable, ConnectorError>Expand description
Opens an existing Delta Lake table or creates a new one.
Arguments
table_path- Path to the Delta Lake table (local,s3://,az://,gs://)storage_options- Storage credentials and configurationschema- Optional Arrow schema for table creation (required if table doesn’t exist)
Returns
The opened DeltaTable handle.
Errors
Returns ConnectorError::ConnectionFailed if the table cannot be opened or created.