pub fn register_delta_lake_sink(
registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>Expand description
Registers the Delta Lake sink connector with the given registry.
Errors
Returns the registry error when a name is already registered or the registry is frozen.