pub fn register_delta_lake_sink(registry: &ConnectorRegistry)Expand description
Registers the Delta Lake sink connector with the given registry.
pub fn register_delta_lake_sink(registry: &ConnectorRegistry)Registers the Delta Lake sink connector with the given registry.