pub fn register_delta_lake_source(
registry: &ConnectorRegistry,
) -> Result<(), ConnectorError>Expand description
Registers the Delta Lake source connector with the given registry.
Errors
Returns the registry error when a name is already registered or the registry is frozen.