pub fn register_delta_lake_source(registry: &ConnectorRegistry)Expand description
Registers the Delta Lake source connector with the given registry.
pub fn register_delta_lake_source(registry: &ConnectorRegistry)Registers the Delta Lake source connector with the given registry.