pub fn register_iceberg_sink(registry: &ConnectorRegistry)Expand description
Registers the Iceberg sink connector with the given registry.
pub fn register_iceberg_sink(registry: &ConnectorRegistry)Registers the Iceberg sink connector with the given registry.