pub fn register_iceberg_source(registry: &ConnectorRegistry)Expand description
Registers the Iceberg source connector with the given registry.
pub fn register_iceberg_source(registry: &ConnectorRegistry)Registers the Iceberg source connector with the given registry.