pub struct WebSocketSourceMetrics {
pub messages_received: AtomicU64,
pub messages_dropped_backpressure: AtomicU64,
pub bytes_received: AtomicU64,
pub reconnect_count: AtomicU64,
pub parse_errors: AtomicU64,
pub sequence_gaps: AtomicU64,
pub connected_clients: AtomicU64,
}Expand description
Atomic counters for WebSocket source connector statistics.
All counters use Relaxed ordering for maximum throughput on the
hot path. Snapshot reads via to_connector_metrics
provide a consistent-enough view for monitoring purposes.
Fields
messages_received: AtomicU64Total messages received from the WebSocket connection.
messages_dropped_backpressure: AtomicU64Total messages dropped due to backpressure.
bytes_received: AtomicU64Total bytes received (raw payload, before parsing).
reconnect_count: AtomicU64Total number of reconnection attempts.
parse_errors: AtomicU64Total parse/deserialization errors.
sequence_gaps: AtomicU64Total detected sequence gaps (application-level).
connected_clients: AtomicU64Current number of connected clients (for server-mode source).
Implementations
Sourceimpl WebSocketSourceMetrics
impl WebSocketSourceMetrics
Sourcepub fn record_message(&self, bytes: u64)
pub fn record_message(&self, bytes: u64)
Records a successfully received message with the given payload size.
Sourcepub fn record_drop(&self)
pub fn record_drop(&self)
Records a message dropped due to backpressure.
Sourcepub fn record_reconnect(&self)
pub fn record_reconnect(&self)
Records a reconnection attempt.
Sourcepub fn record_parse_error(&self)
pub fn record_parse_error(&self)
Records a parse/deserialization error.
Sourcepub fn record_sequence_gap(&self)
pub fn record_sequence_gap(&self)
Records a detected sequence gap.
Sourcepub fn set_connected_clients(&self, n: u64)
pub fn set_connected_clients(&self, n: u64)
Sets the current number of connected clients (server-mode source).
Sourcepub fn to_connector_metrics(&self) -> ConnectorMetrics
pub fn to_connector_metrics(&self) -> ConnectorMetrics
Converts to the SDK’s ConnectorMetrics.